@@ -17,7 +17,7 @@ from chaosgcp.types import GCPContext
 
 __all__ = ["__version__", "client", "discover", "get_context", "get_service",
            "wait_on_operation", "load_credentials"]
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 
 def get_service(service_name: str, version: str = 'v1',
@@ -174,4 +174,6 @@ def load_exported_activities() -> List[DiscoveredActivities]:
     activities.extend(discover_actions("chaosgcp.sql.actions"))
     activities.extend(discover_probes("chaosgcp.sql.probes"))
     activities.extend(discover_probes("chaosgcp.storage.probes"))
+    activities.extend(discover_probes("chaosgcp.cloudbuild.actions"))
+    activities.extend(discover_probes("chaosgcp.cloudbuild.probes"))
     return activities
